@@ -15,12 +15,16 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ContentHandler.h,v 1.12 2004/01/21 23:39:42 marco Exp $
+ *  $Id: ContentHandler.h,v 1.14.4.2 2004/05/07 13:55:32 chpe Exp $
  */
 
 #ifndef __ContentHandler_h
 #define __ContentHandler_h
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "ephy-embed-shell.h"
 
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
@@ -43,6 +47,7 @@
 typedef enum
 {
 	CONTENT_ACTION_OPEN,
+	CONTENT_ACTION_OPEN_TMP,
 	CONTENT_ACTION_DOWNLOAD,
 	CONTENT_ACTION_SAVEAS,
 	CONTENT_ACTION_NONE
@@ -81,7 +86,11 @@ class GContentHandler : public nsIHelperAppLauncherDialog
 	nsCOMPtr<nsIFile> mTempFile;
 	nsCOMPtr<nsISupports> mContext;
 
-	char *mMimeType;	
+#if MOZILLA_SNAPSHOT < 18
+	char *mMimeType;
+#else
+	nsCString mMimeType;
+#endif	
 	PRBool mAppSupportScheme;
 	GnomeVFSMimeApplication *mHelperApp;
 	ContentAction mAction;
