@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.cpp,v 1.22.4.4 2004/05/15 16:20:12 chpe Exp $
+ *  $Id: EphyBrowser.cpp,v 1.22.4.8 2004/07/31 15:48:28 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -83,6 +83,12 @@
 #include "nsPromiseFlatString.h"
 #include "nsString.h"
 #include "ContentHandler.h"
+#include "MozillaPrivate.h"
+#include "print-dialog.h"
+
+#if MOZILLA_SNAPSHOT >= 17
+#include "nsIDOMWindow2.h"
+#endif
 
 EphyEventListener::EphyEventListener(void)
 : mOwner(nsnull)
@@ -242,7 +248,16 @@ EphyBrowser::GetListener (void)
 
   	nsCOMPtr<nsIDOMWindow> domWindowExternal;
   	mWebBrowser->GetContentDOMWindow(getter_AddRefs(domWindowExternal));
-  
+
+#if MOZILLA_SNAPSHOT >= 17
+	nsCOMPtr<nsIDOMWindow2> domWindow (do_QueryInterface (domWindowExternal));
+	NS_ENSURE_TRUE (domWindow, NS_ERROR_FAILURE);
+
+	nsCOMPtr<nsIDOMEventTarget> rootWindow;
+	domWindow->GetWindowRoot (getter_AddRefs (rootWindow));
+
+	mEventReceiver = do_QueryInterface (rootWindow);
+#else
   	nsCOMPtr<nsIDOMWindowInternal> domWindow;
         domWindow = do_QueryInterface(domWindowExternal);
 	
@@ -253,6 +268,8 @@ EphyBrowser::GetListener (void)
   	piWin->GetChromeEventHandler(getter_AddRefs(chromeHandler));
 
   	mEventReceiver = do_QueryInterface(chromeHandler);
+#endif /* MOZILLA_SNAPSHOT >= 17 */
+
 	NS_ENSURE_TRUE (mEventReceiver, NS_ERROR_FAILURE);
 
 	return NS_OK;
@@ -301,43 +318,49 @@ EphyBrowser::DetachListeners(void)
 	return NS_OK;
 }
 
-nsresult EphyBrowser::Print (nsIPrintSettings *options, PRBool preview)
+nsresult EphyBrowser::Print ()
 {
-	nsresult result;
+	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
+
+	nsCOMPtr<nsIWebBrowserPrint> print(do_GetInterface(mWebBrowser));
+	NS_ENSURE_TRUE (print, NS_ERROR_FAILURE);
+
+	return  print->Print (nsnull, nsnull);
+}
+
+nsresult EphyBrowser::SetPrintPreviewMode (PRBool previewMode)
+{
+	nsresult rv;
 
 	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
 
 	nsCOMPtr<nsIWebBrowserPrint> print(do_GetInterface(mWebBrowser));
 	NS_ENSURE_TRUE (print, NS_ERROR_FAILURE);
 
-	if (!preview)
+	if (previewMode)
 	{
-		result = print->Print (options, nsnull);
+		EmbedPrintInfo *info;
+
+		nsCOMPtr<nsIPrintSettings> settings;
+		print->GetGlobalPrintSettings (getter_AddRefs(settings));
+
+		info = ephy_print_get_print_info ();
+		MozillaCollatePrintSettings (info, settings, TRUE);
+		ephy_print_info_free (info);
+
+		rv = print->PrintPreview (nsnull, mDOMWindow, nsnull);
 	}
 	else
 	{
-		result = print->PrintPreview(options, nsnull, nsnull);
-	}
+		PRBool isPreview = PR_FALSE;
 
-	return result;
-}
+		rv = print->GetDoingPrintPreview(&isPreview);
+		NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
-nsresult EphyBrowser::PrintPreviewClose (void)
-{
-	nsresult rv;
-	PRBool isPreview = PR_FALSE;
-
-	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
-
-	nsCOMPtr<nsIWebBrowserPrint> print(do_GetInterface(mWebBrowser));
-	NS_ENSURE_TRUE (print, NS_ERROR_FAILURE);
-
-	rv = print->GetDoingPrintPreview(&isPreview);
-	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
-
-	if (isPreview == PR_TRUE)
-	{
-		rv = print->ExitPrintPreview();
+		if (isPreview == PR_TRUE)
+		{
+			rv = print->ExitPrintPreview();
+		}
 	}
 
 	return rv;
@@ -363,16 +386,6 @@ nsresult EphyBrowser::PrintPreviewNavigate(PRInt16 navType, PRInt32 pageNum)
 	return print->PrintPreviewNavigate(navType, pageNum);
 }
 
-nsresult EphyBrowser::GetPrintSettings (nsIPrintSettings **options)
-{
-	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
-
-	nsCOMPtr<nsIWebBrowserPrint> print(do_GetInterface(mWebBrowser));
-	NS_ENSURE_TRUE (print, NS_ERROR_FAILURE);
-
-	return print->GetGlobalPrintSettings(options);
-}
-
 nsresult EphyBrowser::GetSHistory (nsISHistory **aSHistory)
 {
 	nsresult result;
@@ -415,6 +428,44 @@ nsresult EphyBrowser::GoToHistoryIndex (PRInt16 index)
 	return ContentNav->GotoIndex (index);
 }
 
+/* Workaround for broken reload with frames, see mozilla bug
+ * http://bugzilla.mozilla.org/show_bug.cgi?id=246392
+ */
+nsresult EphyBrowser::Reload (PRUint32 flags)
+{
+	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
+
+	nsCOMPtr<nsISHistory> sessionHistory;
+	GetSHistory (getter_AddRefs (sessionHistory));
+
+	nsCOMPtr<nsIWebNavigation> webNavigation;
+	webNavigation = do_QueryInterface (sessionHistory);
+
+	if (!webNavigation)
+	{
+		webNavigation = do_QueryInterface (mWebBrowser);
+	}
+	NS_ENSURE_TRUE (webNavigation, NS_ERROR_FAILURE);
+
+	PRUint32 reloadFlags;
+	switch (flags)
+	{
+		case RELOAD_FORCE:
+			reloadFlags = nsIWebNavigation::LOAD_FLAGS_BYPASS_CACHE | 
+				      nsIWebNavigation::LOAD_FLAGS_BYPASS_PROXY;
+			break;
+		case RELOAD_ENCODING_CHANGE:
+			reloadFlags = nsIWebNavigation::LOAD_FLAGS_CHARSET_CHANGE;
+			break;
+		case RELOAD_NORMAL:
+		default:
+			reloadFlags = 0;
+			break;
+	}
+
+	return webNavigation->Reload (reloadFlags);
+}
+ 
 nsresult EphyBrowser::SetZoom (float aZoom, PRBool reflow)
 {
 	if (!mWebBrowser) return NS_ERROR_FAILURE;
@@ -574,7 +625,7 @@ nsresult EphyBrowser::GetSHTitleAtIndex (PRInt32 index, PRUnichar **title)
 	return NS_OK;
 }
 
-nsresult EphyBrowser::GetSHUrlAtIndex (PRInt32 index, nsCString &url)
+nsresult EphyBrowser::GetSHUrlAtIndex (PRInt32 index, nsACString &url)
 {
 	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
 
@@ -642,7 +693,7 @@ nsresult EphyBrowser::GetPageDescriptor(nsISupports **aPageDescriptor)
 	return NS_OK;
 }
 
-nsresult EphyBrowser::GetDocumentUrl (nsCString &url)
+nsresult EphyBrowser::GetDocumentUrl (nsACString &url)
 {
 	NS_ENSURE_TRUE (mDOMWindow, NS_ERROR_FAILURE);
 
@@ -668,7 +719,7 @@ nsresult EphyBrowser::GetDocumentUrl (nsCString &url)
 	return uri->GetSpec (url);
 }
 
-nsresult EphyBrowser::GetTargetDocumentUrl (nsCString &url)
+nsresult EphyBrowser::GetTargetDocumentUrl (nsACString &url)
 {
 	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
 
