@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyContentPolicy.cpp,v 1.1.4.1 2004/05/14 16:44:39 chpe Exp $
+ *  $Id: EphyContentPolicy.cpp,v 1.1.4.3 2004/07/31 15:46:35 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -62,7 +62,11 @@ NS_IMETHODIMP
 EphyContentPolicy::ShouldLoad(PRUint32 aContentType,
 			      nsIURI *aContentLocation,
 			      nsIURI *aRequestingLocation,
+#if MOZILLA_SNAPSHOT >= 20
+			      nsISupports *aContext,
+#else
 			      nsIDOMNode *aRequestingNode,
+#endif
 			      const nsACString &aMimeTypeGuess,
 			      nsISupports *aExtra,
 			      PRInt16 *aDecision)
@@ -101,7 +105,11 @@ NS_IMETHODIMP
 EphyContentPolicy::ShouldProcess(PRUint32 aContentType,
 			         nsIURI *aContentLocation,
 			         nsIURI *aRequestingLocation,
+#if MOZILLA_SNAPSHOT >= 20
+			         nsISupports *aContext,
+#else
 			         nsIDOMNode *aRequestingNode,
+#endif
 			         const nsACString &aMimeType,
 			         nsISupports *aExtra,
 			         PRInt16 *aDecision)
