@@ -15,14 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-file-helpers.h,v 1.8 2004/01/25 00:38:46 marco Exp $
+ *  $Id: ephy-file-helpers.h,v 1.9.4.1 2004/07/22 09:29:42 chpe Exp $
  */
 
 #ifndef EPHY_FILE_HELPERS_H
 #define EPHY_FILE_HELPERS_H
 
 #include <glib.h>
-#include <libxml/tree.h>
 
 G_BEGIN_DECLS
 
@@ -41,7 +40,7 @@ const char *ephy_file_tmp_dir	 	 (void);
 char       *ephy_file_tmp_filename	 (const char *base,
 					  const char *extension);
 
-void	    ephy_ensure_dir_exists       (const char *dir);
+gboolean    ephy_ensure_dir_exists       (const char *dir);
 
 GSList     *ephy_file_find               (const char *path,
 				          const char *fname,
