@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-window.h,v 1.23 2004/02/24 17:43:48 chpe Exp $
+ *  $Id: ephy-window.h,v 1.23.4.1 2004/03/22 09:21:31 marco Exp $
  */
 
 #ifndef EPHY_WINDOW_H
@@ -57,12 +57,6 @@ struct EphyWindowClass
         GtkWindowClass parent_class;
 };
 
-typedef enum
-{
-	NormalMode,
-	FullscreenMode
-} EphyWindowMode;
-
 /* Include the header down here to resolve circular dependency */
 #include "ephy-tab.h"
 #include "ephy-notebook.h"
@@ -71,8 +65,7 @@ GType		  ephy_window_get_type		  (void);
 
 EphyWindow	 *ephy_window_new		  (void);
 
-void		  ephy_window_request_chrome	  (EphyWindow *window,
-						   EmbedChromeMask chrome_flags);
+EphyWindow	 *ephy_window_new_with_chrome	  (EphyEmbedChrome chrome);
 
 void		  ephy_window_set_print_preview	  (EphyWindow *window,
 						   gboolean enabled);
